@@ -16,7 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Global variables.
 our %ERR_PARAMETERS;
@@ -47,13 +47,7 @@ sub err {
 
 	# Die for eval.
 	} else {
-		my $e = $errors[-1]->{'msg'}->[0];
-		if (! defined $e) {
-			$e = 'undef';
-		} else {
-			chomp $e;
-		}
-		die "$e\n";
+		die "$errors[-1]->{'msg'}->[0]\n";
 	}
 
 	return;
@@ -212,10 +206,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2013-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
